@@ -130,23 +130,31 @@ def validate_rules(rules: Dict[str, Union[Rule, bool]]):
 
 
 def get_last_matching_index(matchers: Sequence[str], name: str):
-    for i, matcher in reversed(list(enumerate(matchers))):
+    index = None
+    for i, (matcher, rule) in list(enumerate(matchers.items())):
         if re.match(matcher, name):
-            return i
-    raise ValueError()
+            if rule is not True or index is None:
+                index = i
+    if index is None:
+        raise ValueError()
+    return index
 
 
 def get_last_matching_value(matchers, name, field, default):
+    has_match = False
     for matcher, rule in reversed(list(matchers.items())):
         if re.match(matcher, name):
             if rule is False:
                 return matcher, False
             elif rule is True:
-                return matcher, default
+                has_match = True
             else:
                 field_value = getattr(rule, field)
+                has_match = True
                 if field_value is not None:
                     return matcher, field_value
+    if not has_match:
+        return None, False
     return None, default
 
 
